@@ -79,6 +79,10 @@
  *  	
  *  	20/03/03  ranjeeth		Made to work for Linux Advanced server.
  *  					Taken care of license warning.	
+ *      
+ *	10/12/03  Ravindra		Made to work for Fedora Core 1 of 
+ *					Red Hat Distribution
+ *      
  *	***********************************************************
  *
  *	To use this driver you also need the support package. You 
@@ -1543,8 +1547,15 @@ static void isicom_close(struct tty_struct * tty, struct file * filp)
 		spin_unlock_irqrestore(&card->card_lock, flags);
 		return;
 	}
-	
+
+#if LINUX_VERSION_CODE < 132118	
+				/* Changed by Ravindra as per the definition 
+				   of tty->count in Fedora core */
 	if ((tty->count == 1) && (port->count != 1)) {
+#else		
+	if ((atomic_read(&tty->count) == 1) && (port->count != 1)) {
+#endif
+		
 		printk(KERN_WARNING "ISICOM:(0x%x) isicom_close: bad port count"
 			"tty->count = 1	port count = %d.\n",
 			card->base, port->count);
